<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Rma Hyva Compatibility
 */

declare(strict_types=1);

namespace Amasty\RmaHyva\Block\Link;

use Magento\Framework\View\Element\Html\Link\Current;
use Magento\Framework\View\Element\Template\Context;
use Amasty\Rma\Model\ConfigProvider;
use Magento\Framework\App\DefaultPathInterface;

class CustomerLink extends Current implements \Magento\Customer\Block\Account\SortLinkInterface
{

    /**
     * @var ConfigProvider $configProvider
     */
    private $configProvider;

    /**
     * @param Context $context
     * @param ConfigProvider $configProvider
     * @param DefaultPathInterface $defaultPath
     * @param array $data
     */
    public function __construct(
        Context $context,
        ConfigProvider $configProvider,
        DefaultPathInterface $defaultPath,
        array $data = []
    ) {
        parent::__construct($context, $defaultPath, $data);
        $this->configProvider = $configProvider;
    }

    /**
     * Render if module enabled
     *
     * @return string
     */
    public function toHtml()
    {
        if (!$this->configProvider->isEnabled()) {
            return '';
        }

        return parent::toHtml();
    }

    /**
     * Get Sorting Order
     *
     * @return string
     */
    public function getSortOrder()
    {
        return $this->getData(self::SORT_ORDER);
    }

    /**
     * Set default label
     *
     * @return string
     */
    public function getLabel()
    {
        return __('My Returns');
    }

    /**
     * Get link path
     *
     * @return string
     */
    public function getPath()
    {
        if (!$this->getData('path')) {
            $this->setData('path', $this->configProvider->getUrlPrefix() . '/account/history');
        }

        return $this->getData('path');
    }
}
