<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Rma Hyva Compatibility
 */
declare(strict_types=1);

namespace Amasty\RmaHyva\ViewModel;

use Magento\Framework\App\ProductMetadata;
use Magento\Framework\App\ProductMetadataInterface;
use Magento\Framework\View\Element\Block\ArgumentInterface;

class GraphQlQueries implements ArgumentInterface
{
    /**
     * Add Tracking Number
     *
     * @return string
     */
    public function addTrackingNumber(): string
    {
        return 'addAmRmaTrackingNumber(
            input: {
                hash: $hash,
                code: $code,
                number: $number
            }) {
                tracking_id,
                request_id,
                tracking_code,
                tracking_number,
                is_customer
            }';
    }

    /**
     * Remove Tracking Number
     *
     * @return string
     */
    public function removeTrackingNumber(): string
    {
        return 'removeAmRmaTrackingNumber(
            input: {
                hash: $hash,
                tracking_id: $tracking_id
            }) {
                error,
                message
            }';
    }

    /**
     * Send Message
     *
     * @return string
     */
    public function sendMessage(): string
    {
        return 'sendAmRmaMessage(
            input: {
                hash: $hash,
                message: $message,
                files: $files
            }) {
                message_id,
                username,
                message,
                created,
                is_manager,
                is_system,
                files {
                    filename,
                    filepath
                }
            }';
    }

    /**
     * Get Messages
     *
     * @return string
     */
    public function getMessages(): string
    {
        return 'getAmRmaRequestMessages(hash: $hash, last_message_id: $last_message_id)
            {
                message_id,
                username,
                message,
                created,
                is_manager,
                is_system,
                files {
                    filename,
                    filepath
                }
            }';
    }

    /**
     * Remove Message
     *
     * @return string
     */
    public function removeMessage(): string
    {
        return 'deleteAmRmaMessage(input: {hash: $hash, message_id: $message_id})
            {
                error,
                message
            }';
    }

    /**
     * Delete File
     *
     * @return string
     */
    public function deleteFile(): string
    {
        return 'deleteAmRmaMessageFile(filehash: $filehash)
            {
                error,
                message
            }';
    }
}
