<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Rma Hyva Compatibility
 */
declare(strict_types=1);

namespace Amasty\RmaHyva\ViewModel;

use Amasty\Rma\Model\ConfigProvider;
use Magento\Customer\Model\Context;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Http\Context as HttpContext;
use Magento\Framework\Phrase;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Framework\UrlInterface;

class RmaConfigData implements ArgumentInterface
{
    /** @var string  */
    public const XML_PATH_AMASTY_RMA_CUSTOM_ID_ENABLED = 'amrma/custom_id/custom_id_enabled';

    /**
     * Amasty configuration model
     *
     * @var ConfigProvider
     */
    private ConfigProvider $configProvider;

    /**
     * Url Builder Interface
     *
     * @var UrlInterface
     */
    private UrlInterface $urlBuilder;

    /**
     * @var HttpContext
     */
    private HttpContext $httpContext;

    /**
     * @var ScopeConfigInterface
     */
    private ScopeConfigInterface $scopeConfig;

    /**
     * @param ConfigProvider $configProvider
     * @param UrlInterface $urlBuilder
     * @param HttpContext $httpContext
     */
    public function __construct(
        ConfigProvider $configProvider,
        UrlInterface $urlBuilder,
        HttpContext $httpContext,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->configProvider = $configProvider;
        $this->urlBuilder = $urlBuilder;
        $this->httpContext = $httpContext;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * Check URL Prefix from Admin configuration entry
     *
     * @return string
     */
    public function getUrlPrefix(): string
    {
        return $this->configProvider->getUrlPrefix();
    }

    /**
     * Get max upload file size in chat
     *
     * @return int
     */
    public function getMaxFileSize(): int
    {
        return $this->configProvider->getMaxFileSize();
    }

    /**
     * Get link path
     *
     * @return string
     */
    public function getPath(): string
    {
        return $this->urlBuilder->getUrl(
            sprintf(
                '%s/%s',
                $this->getUrlPrefix(),
                $this->isLoggedIn() ? 'account/history' : 'requests'
            )
        );
    }

    /**
     * Get link label
     *
     * @return Phrase
     */
    public function getLabel(): Phrase
    {
        return $this->isLoggedIn()
            ? __('My Returns')
            : __('Return Requests');
    }

    /**
     * Is Customer LoggedIn
     *
     * @return bool
     */
    private function isLoggedIn(): bool
    {
        return (bool)$this->httpContext->getValue(Context::CONTEXT_AUTH);
    }

    /**
     * Is Custom Number id enabled
     *
     * @return bool
     */
    public function isCustomIdEnabled(): bool
    {
        return $this->scopeConfig->isSetFlag(
            self::XML_PATH_AMASTY_RMA_CUSTOM_ID_ENABLED
        ) ?? false;
    }
}
